@@ -165,9 +165,9 @@ class Action():
 
                 text = item["text"]
                 
-                print("type: ", type(update))
-                print("update: ", update)
-                print("context: ", str(context.user_data))
+                logger.debug("type: ", type(update))
+                logger.debug("update: ", update)
+                logger.debug("context: ", str(context.user_data))
                 if type(update) == CallbackQuery:
                     update.from_user.send_message(text.format(
                         **context.user_data), reply_markup=reply_markup, parse_mode=parse_mode, disable_web_page_preview=disable_web_page_preview)
