@@ -1,3 +1,4 @@
+import re
 import yaml
 from telegram import Update
 from telegram.ext import (CommandHandler, Filters, MessageHandler,
@@ -7,14 +8,17 @@ from digitalguide import rasa_filter, uhrzeit_filter
 from digitalguide.pattern import (EMOJI_PATTERN, JA_PATTERN, NEIN_PATTERN,
                                   WEITER_PATTERN, WOHIN_PATTERN, ZURUECK_PATTERN)
 
+def read_state_yml(filename, actions: dict = None, prechecks: list = None):
+    with open(filename) as file:
+        yaml_dict = yaml.load(file, Loader=yaml.FullLoader)
 
-def read_state_yml(filename, actions=None, prechecks: list = None):
+    return read_state(yaml_dict, actions=actions, prechecks=prechecks)
+
+def read_state(yaml_dict, actions: dict = None, prechecks: list = None):
     if actions is None:
         actions = {}
     if prechecks is None:
         prechecks = []
-    with open(filename) as file:
-        yaml_dict = yaml.load(file, Loader=yaml.FullLoader)
 
     states_dict = {}
 
@@ -43,7 +47,7 @@ def read_state_yml(filename, actions=None, prechecks: list = None):
                             ZURUECK_PATTERN), actions[handler["action"]])
                     else:
                         newHandler = MessageHandler(Filters.regex(
-                            handler["regex"]), actions[handler["action"]])
+                            re.compile(handler["regex"],re.IGNORECASE)), actions[handler["action"]])
                 elif handler["filter"] == "text":
                     newHandler = MessageHandler(
                         Filters.text, actions[handler["action"]])
@@ -70,6 +74,9 @@ def read_state_yml(filename, actions=None, prechecks: list = None):
             elif handler["handler"] == "TypeHandler":
                 if handler["type"] == "Update":
                     type_ = Update
+                else:
+                    raise NotImplementedError(
+                    "This Updatetype is not implemented: {}".format(handler["type"]))
                 newHandler = TypeHandler(type_, actions[handler["action"]])
             else:
                 raise NotImplementedError(
