@@ -1,3 +1,4 @@
+import logging
 from google import auth
 from telegram.ext import MessageFilter
 import requests as req
@@ -9,6 +10,12 @@ import json
 config = ConfigParser() 
 config.read('config.ini')
 
+logging.basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
+                    level=logging.INFO)
+
+logger = logging.getLogger(__name__)
+
+
 class FilterRasa(MessageFilter):
     def __init__(self, intent, confidence=0.8):
         self.intent = intent
@@ -22,13 +29,13 @@ class FilterRasa(MessageFilter):
             })
 
             token_response = req.post(config["rasa"]["url"] + "/api/auth", data=payload)
-            print(token_response.json())
+            logger.debug(token_response.json())
 
             RASA_TOKEN = token_response.json()["access_token"]
             response = req.post(config["rasa"]["url"] + "/api/projects/default/logs", params={"q": message.text}, headers={'Authorization': 'Bearer {}'.format(RASA_TOKEN)},  timeout = (3, 8))
-            print(response.json())
+            logger.debug(response.json())
         except (Timeout, KeyError) as e:
-            print(e)
+            logger.error(e)
             False
         else:
             if not response.ok:
