@@ -1,5 +1,6 @@
 
 from collections import defaultdict
+from digitalguide.pattern import JAHRESZAHL_PATTERN, KOMMAZAHL_PATTERN
 from digitalguide.standardinteraktion.Action import readActions
 from digitalguide.standardinteraktion.Trigger import readTriggers
 
@@ -114,22 +115,22 @@ class Interaktion:
                 interaktion_dict["Tipp"], messanger=messanger, asset_url=asset_url)
 
             if interaktion_dict["Typ"][0][0] == "Jahreszahl":
-                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "^(\d{1,4})$")], "{}_aufloesung".format(poi_name))) \
+                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", JAHRESZAHL_PATTERN)], "{}_aufloesung".format(poi_name))) \
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
             elif interaktion_dict["Typ"][0][0] == "Prozentzahl":
-                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "(\d{1,2}),? ?(\d{,2})")], "{}_aufloesung".format(poi_name))) \
+                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", KOMMAZAHL_PATTERN)], "{}_aufloesung".format(poi_name))) \
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
             elif interaktion_dict["Typ"][0][0] == "Kommazahl":
-                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "(\d{1,2}),? ?(\d{,2})")], "{}_aufloesung".format(poi_name))) \
+                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", KOMMAZAHL_PATTERN)], "{}_aufloesung".format(poi_name))) \
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
             elif interaktion_dict["Typ"][0][0] == "Länge":
-                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "(?P<cm>(?P<cm_zahl>\d{1,}),?(?P<cm_komma>\d{1,})? ?(cm|CM|Cm))")], "{}_aufloesung".format(poi_name))) \
+                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", KOMMAZAHL_PATTERN)], "{}_aufloesung".format(poi_name))) \
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
