@@ -1,4 +1,5 @@
 import json
+import logging
 import os
 import re
 from configparser import ConfigParser
@@ -16,6 +17,9 @@ def read_state_yml(filename, actions={}, prechecks: List = []):
     with open(filename) as file:
         yaml_dict = yaml.load(file, Loader=yaml.FullLoader)
 
+    return read_state(yaml_dict, actions=actions, prechecks=prechecks)
+
+def read_state(yaml_dict, actions={}, prechecks: List = []):
     states_dict = {}
 
     for state, handlers in yaml_dict.items():
@@ -59,13 +63,22 @@ def read_state_yml(filename, actions={}, prechecks: List = []):
                 elif handler["filter"] == "rasa":
                     newHandler = MessageHandler(FilterRasa(
                         handler["intent"]), actions[handler["action"]])
+                else:
+                    raise NotImplementedError(
+                        "This Filter is not implemented: {}".format(handler["filter"]))
             elif handler["handler"] == "CommandHandler":
                 newHandler = CommandHandler(
                     handler["command"], actions[handler["action"]])
             elif handler["handler"] == "TypeHandler":
                 if handler["type"] == "Update":
                     type_ = WhatsAppUpdate
+                else:
+                    raise NotImplementedError(
+                    "This Updatetype is not implemented: {}".format(handler["type"]))
                 newHandler = TypeHandler(type_, actions[handler["action"]])
+            else:
+                raise NotImplementedError(
+                    "This Handler is not implemented: {}".format(handler["handler"]))
 
             handler_list.append(newHandler)
 
@@ -107,7 +120,7 @@ class RegexFilter:
         self.regex = regex
 
     def __call__(self, update: WhatsAppUpdate) -> bool:
-        return re.match(self.regex, update.Body)
+        return re.search(self.regex, update.Body)
 
 
 class TextFilter:
@@ -128,6 +141,11 @@ class VoiceFilter:
 config = ConfigParser()
 config.read('config.ini')
 
+logging.basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
+                    level=logging.INFO)
+
+logger = logging.getLogger(__name__)
+
 
 class FilterRasa:
     def __init__(self, intent, confidence=0.8):
@@ -143,14 +161,14 @@ class FilterRasa:
 
             token_response = req.post(
                 config["rasa"]["url"] + "/api/auth", data=payload)
-            print(token_response.json())
+            logger.debug(token_response.json())
 
             RASA_TOKEN = token_response.json()["access_token"]
             response = req.post(config["rasa"]["url"] + "/api/projects/default/logs", params={
                                 "q": update.Body}, headers={'Authorization': 'Bearer {}'.format(RASA_TOKEN)},  timeout=(3, 8))
-            print(response.json())
+            logger.debug(response.json())
         except (Timeout, KeyError) as e:
-            print(e)
+            logger.debug(e)
             False
         else:
             if not response.ok:
